<template>
  <Dialog :title="dialogTitle" v-model="dialogVisible">
    <el-form
      ref="formRef"
      :model="formData"
      :rules="formRules"
      label-width="100px"
      v-loading="formLoading"
    >
      <el-form-item label="模型id" prop="modelId">
        <el-input v-model="formData.modelId" placeholder="请输入模型id" />
      </el-form-item>
      <el-form-item label="问题编号" prop="questionCode">
        <el-input v-model="formData.questionCode" placeholder="请输入问题编号" />
      </el-form-item>
      <el-form-item label="问题名称" prop="questionName">
        <el-input v-model="formData.questionName" placeholder="请输入问题名称" />
      </el-form-item>
      <el-form-item label="问题内容" prop="questionContent">
        <Editor v-model="formData.questionContent" height="150px" />
      </el-form-item>
      <el-form-item label="输入个数" prop="dataLength">
        <el-input v-model="formData.dataLength" placeholder="请输入输入个数" />
      </el-form-item>
      <el-form-item label="是否启用（0禁用 1启用）" prop="isEnable">
        <el-input v-model="formData.isEnable" placeholder="请输入是否启用（0禁用 1启用）" />
      </el-form-item>
      <el-form-item label="备注" prop="remark">
        <el-input v-model="formData.remark" placeholder="请输入备注" />
      </el-form-item>
      <el-form-item label="创建时间" prop="createDate">
        <el-date-picker
          v-model="formData.createDate"
          type="date"
          value-format="x"
          placeholder="选择创建时间"
        />
      </el-form-item>
      <el-form-item label="更新者" prop="updator">
        <el-input v-model="formData.updator" placeholder="请输入更新者" />
      </el-form-item>
      <el-form-item label="更新时间" prop="updateDate">
        <el-date-picker
          v-model="formData.updateDate"
          type="date"
          value-format="x"
          placeholder="选择更新时间"
        />
      </el-form-item>
    </el-form>
    <template #footer>
      <el-button @click="submitForm" type="primary" :disabled="formLoading">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script setup lang="ts">
import { QuestionTemplateApi, QuestionTemplateVO } from '@/api/ai/questiontemplate'

/** 大模型问题模板 表单 */
defineOptions({ name: 'QuestionTemplateForm' })

const { t } = useI18n() // 国际化
const message = useMessage() // 消息弹窗

const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  modelId: undefined,
  questionCode: undefined,
  questionName: undefined,
  questionContent: undefined,
  dataLength: undefined,
  isEnable: undefined,
  remark: undefined,
  createDate: undefined,
  updator: undefined,
  updateDate: undefined,
})
const formRules = reactive({
  modelId: [{ required: true, message: '模型id不能为空', trigger: 'blur' }],
  questionCode: [{ required: true, message: '问题编号不能为空', trigger: 'blur' }],
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await QuestionTemplateApi.getQuestionTemplate(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({ open }) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  await formRef.value.validate()
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as QuestionTemplateVO
    if (formType.value === 'create') {
      await QuestionTemplateApi.createQuestionTemplate(data)
      message.success(t('common.createSuccess'))
    } else {
      await QuestionTemplateApi.updateQuestionTemplate(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    modelId: undefined,
    questionCode: undefined,
    questionName: undefined,
    questionContent: undefined,
    dataLength: undefined,
    isEnable: undefined,
    remark: undefined,
    createDate: undefined,
    updator: undefined,
    updateDate: undefined,
  }
  formRef.value?.resetFields()
}
</script>